@@ -1,5 +1,6 @@
 import json
 import logging
+import time
 import os
 
 from FLIR.conservator.generated import schema
@@ -358,6 +359,47 @@ class Dataset(QueryableType, FileLockerType, MetadataType):
         """
         self.download_blob_by_name("index.json", path, commit_id="HEAD")
 
+    def wait_for_history_len(self, num_expected_commits, max_tries=10):
+        """
+        Waits until the number of commits in Dataset's history is at least the
+        requested number. Intended as heuristic for checking whether a recent
+        commit has finished processing on the server, though it could be
+        misleading if multiple commits are being pushed to the dataset from
+        different sources (e.g. if local clone and web UI are being used
+        to make changes in parallel)
+        """
+        got_new_commit = False
+        tries = 0
+        while tries < max_tries:
+            self.populate(fields="git_commit_state")
+            commits = self.get_commit_history()
+            if (
+                len(commits) >= num_expected_commits
+                and self.git_commit_state == "completed"
+            ):
+                got_new_commit = True
+                break
+            else:
+                tries += 1
+                if tries < max_tries:
+                    time.sleep(1)
+                else:
+                    break
+
+        return got_new_commit
+
+    def wait_for_dataset_commit(self):
+        """Wait for the server to create the first commit to a new dataset."""
+        done = False
+        for _ in range(60):
+            time.sleep(1)
+            dset = self._conservator.datasets.from_id(self.id)
+            dset.populate(["git_commit_state"])
+            if dset and dset.git_commit_state == "completed":
+                done = True
+                break
+        return done
+
     @classmethod
     def from_local_path(cls, conservator, path="."):
         """Returns a new Dataset instance using the ID found in ``index.json``
